@@ -73,7 +73,7 @@ class Client:
                 r = self.session.get(f"{self.url}/ai?message={message}&type={type}&language={lang}&uid={unique_id}&master={dev_name}&bot={bot_name}")
                 if r.status_code == 200:
                     r_json = r.json()
-                    return r_json["message"]
+                    return r_json[0]["message"]
                 elif r.status_code in [401, 403]:
                     raise AuthError
                 else:
@@ -207,7 +207,7 @@ class AsyncClient:
                 r = await self.session.get(f"{self.url}/ai?message={message}&type={type}&language={lang}&uid={unique_id}&master={dev_name}&bot={bot_name}")
                 if r.status == 200:
                     r_json = await r.json()
-                    return r_json["message"]
+                    return r_json[0]["message"]
                 elif r.status in [401, 403]:
                     raise AuthError
                 else:
